@@ -13,4 +13,8 @@ def execute(freight_hub_json):
   if delivery_date:
     freight_hub_json_copy['deliveryDate'] = date.fromtimestamp(int(delivery_date)/1000).isoformat()
 
+  available_time = freight_hub_json.get('availableTime')
+  if available_time:
+    freight_hub_json_copy['availableTime'] = date.fromtimestamp(int(available_time) / 1000).isoformat()
+
   return LoadSchema().load(freight_hub_json_copy)
